.. _importwml:

Import and export WaterML timeseries files
==========================================

Import WaterML
--------------

.. include:: ../../HydraPlugins/WaterML/ImportWML/README

.. automodule:: ImportWML
   :members:
